@@ -1,6 +1,6 @@
 package TPath::Selector::Test::ClosestMatch;
 {
-  $TPath::Selector::Test::ClosestMatch::VERSION = '1.000';
+  $TPath::Selector::Test::ClosestMatch::VERSION = '1.001';
 }
 
 # ABSTRACT: handles C</E<gt>~foo~>
@@ -10,7 +10,7 @@ use TPath::Test::Node::Match;
 use namespace::autoclean;
 
 
-with 'TPath::Selector::Test';
+with 'TPath::Selector::Test::Match';
 
 has rx => ( is => 'ro', isa => 'RegexpRef', required => 1 );
 
@@ -29,7 +29,7 @@ sub to_string {
     return
         '/>'
       . ( $self->is_inverted ? '^' : '' )
-      . $self->_stringify_match( $self->rx );
+      . $self->_stringify_match( $self->val );
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -46,7 +46,7 @@ TPath::Selector::Test::ClosestMatch - handles C</E<gt>~foo~>
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 ROLES
 
